NooreTools = {}
NooreTools.name = "NooreTools"
NooreTools.version = "1.6"
NooreTools.throttle = {}
NooreTools.defaults = {
	enabled = false,
	maxGroupSize = 24,
	watchFor = "had00",
	caseSensitive = false,
	onlyInCyrodiil = false,
	watchInZone = false,
	watchInTells = false,
	watchInGuild1 = true,
	watchInGuild2 = true,
	watchInGuild3 = true,
	watchInGuild4 = true,
	watchInGuild5 = true,
	panel = true,
}

local LAM = LibStub("LibAddonMenu-1.0-to-2.0")

function NooreTools.Initialize(eventCode, addOnName)
	-- Only initialize our own addon
	if (NooreTools.name ~= addOnName) then return end

	-- Load the saved variables
	NooreTools.vars = ZO_SavedVars:NewAccountWide("NTVars", 1.6, nil, NooreTools.defaults)

	-- Create config menu
	panelId = LAM:CreateControlPanel(NooreTools.name.."Config", "Noore Tools v" .. NooreTools.version)
	
	LAM:AddHeader(panelId, "NooreTools_Settings_Top", "About")
	LAM:AddDescription(panelId, "NooreTools_Settings_Desc1", 
    "Author: @GlassHalfFull, Citidel, @BrandonNC \nVersion: " .. NooreTools.version .. "\n\nReload the UI (/reloadui) if you join or leave a guild for the changes to appear here.")
	
    LAM:AddHeader(panelId, "\nNooreTools_Settings_Slash", "Slash Commands")
	LAM:AddDescription(panelId, "NooreTools_Settings_Slash1", "/ntenable to turn on NooreTools via the Chat Box")
	LAM:AddDescription(panelId, "NooreTools_Settings_Slash2", "/ntdisable to turn off NooreTools via the Chat Box")
	
    LAM:AddHeader(panelId, "NooreTools_Settings_Heading1", "General")
	LAM:AddCheckbox(panelId, "NooreTools.Enabled", "Enabled", "Enable Group Invites",
			function() return NooreTools.vars.enabled end,
			function(newValue) NooreTools.vars.enabled = newValue end)
	LAM:AddSlider(panelId, "NooreTools.GroupSize", "Group Size", "Maximum Group Size", 2, 24, 1,
			function() return NooreTools.vars.maxGroupSize end,
			function(newValue) NooreTools.vars.maxGroupSize = newValue end)
	
    LAM:AddEditBox(panelId, "NooreTools.WatchForString", "Invite String", "Text to watch for in the selected channels", false,
			function() return NooreTools.vars.watchFor end,
			function(newValue) NooreTools.vars.watchFor = newValue end)
	
    LAM:AddCheckbox(panelId, "NooreTools.CaseSensitive", "Case Sensitive", "Should the invite string be case sensitive",
			function() return NooreTools.vars.caseSensitive end,
			function(newValue) NooreTools.vars.caseSensitive = newValue end)
	
    LAM:AddCheckbox(panelId, "NooreTools.OnlyInCyrodiil", "Cyrodiil Only", "Should you only invite people if you are in Cyrodiil",
			function() return NooreTools.vars.onlyInCyrodiil end,
			function(newValue) NooreTools.vars.onlyInCyrodiil = newValue end,
			true, "Does not affect tells, if they are enabled.")
	
    LAM:AddCheckbox(panelId, "NooreTools.panel", "In-Game Panel", "Lets you toggle the in-game Panel",
			function() return NooreTools.vars.panel end,
			function(newValue) NooreTools.vars.panel = newValue end)
	
    LAM:AddHeader(panelId, "NooreTools.Heading2", "Channels")
	LAM:AddCheckbox(panelId, "NooreTools.ChannelZone", "Zone", nil,
			function() return NooreTools.vars.watchInZone end,
			function(newValue) NooreTools.vars.watchInZone = newValue end)
	LAM:AddCheckbox(panelId, "NooreTools.ChannelTells", "Tells", nil,
			function() return NooreTools.vars.watchInTells end,
			function(newValue) NooreTools.vars.watchInTells = newValue end)
	for i = 1, GetNumGuilds(), 1 do
		LAM:AddCheckbox(panelId, "NooreTools_Settings_ChannelGuild_" .. i,  GetGuildName(GetGuildId(i)), nil,
				function() return NooreTools.vars["watchInGuild"..i] end,
				function(newValue) NooreTools.vars["watchInGuild"..i] = newValue end)
	end	
	
	if NooreTools.vars.panel then 
		NooreToolsWindow:SetHidden(false)
	else
		NooreToolsWindow:SetHidden(true)
	end
	
	if NooreTools.vars.enabled then 
		NooreToolsWindowNooreLabel:SetText("Code Enabled: " .. NooreTools.vars.watchFor)
	else
		NooreToolsWindowNooreLabel:SetText("Code Disabled: " .. NooreTools.vars.watchFor)
	end
    
    NooreTools:RestorePosition()
  
	-- EVENT_CHAT_MESSAGE_CHANNEL
	EVENT_MANAGER:RegisterForEvent("NooreTools", EVENT_CHAT_MESSAGE_CHANNEL, NooreTools.ChatMessage)
    
	EVENT_MANAGER:RegisterForEvent("NooreTools", EVENT_ACTION_LAYER_POPPED, NooreTools.ChatMessage)
	
    -- Slash Commands
	SLASH_COMMANDS["/minfo"] = NooreTools.Report
	SLASH_COMMANDS["/mi"] = NooreTools.Invite
	SLASH_COMMANDS["/mk"] = NooreTools.Kick
	SLASH_COMMANDS["/nticon"] = NooreTools.Icon
	SLASH_COMMANDS["/nticon_hide"] = NooreTools.IconHide
	SLASH_COMMANDS["/nticon_show"] = NooreTools.IconShow
	SLASH_COMMANDS["/ntenable"] = NooreTools.enableIt
	SLASH_COMMANDS["/ntdisable"] = NooreTools.disableIt
end

EVENT_MANAGER:RegisterForEvent("NooreTools", EVENT_ADD_ON_LOADED, NooreTools.Initialize)

function NooreTools:RestorePosition()
	if NooreTools.vars.panel then 
		NooreToolsWindow:SetHidden(false)
	else
		NooreToolsWindow:SetHidden(true)
	end
  local left = NooreTools.vars.left
  local top = NooreTools.vars.top
 
  NooreToolsWindow:ClearAnchors()
  NooreToolsWindow:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, left, top)
end

function NooreTools.OnIndicatorMoveStop()
 NooreTools.vars.left = NooreToolsWindow:GetLeft()
 NooreTools.vars.top = NooreToolsWindow:GetTop()
end

function NooreTools.enableIt()
	NooreTools.vars.enabled = true
end

function NooreTools.disableIt()
	NooreTools.vars.enabled = false
end

function NooreTools.ChatMessage(messageType, channel, fromName, text)
	
	--if tonumber(channel) == 2 then NooreTools.label:SetText(messageType .. "." .. channel .. ": " .. fromName .. " - " .. text) end
	channel = tonumber(channel)
	if NooreTools.vars.enabled then 
		NooreToolsWindowNooreLabel:SetText("Code Enabled: " .. NooreTools.vars.watchFor)
	else
		NooreToolsWindowNooreLabel:SetText("Code Disabled: " .. NooreTools.vars.watchFor)
	end
	
	if NooreTools.vars.panel then 
		NooreToolsWindow:SetHidden(false)
	else
		NooreToolsWindow:SetHidden(true)
	end
	if not NooreTools.vars.enabled then return end
	if channel ~= 2 and GetUnitZone("player") ~= "Cyrodiil" and NooreTools.vars.onlyInCyrodiil then return end
	if IsPlayerInGroup("player") and not IsUnitGroupLeader("player") then return end
	if GetGroupSize() >= NooreTools.vars.maxGroupSize then return end
	
	--[[
		0: say
		1: yell
		2: tell in
		3: group
		4: tell out ??
		12: g1
		13: g2
		14: g3
		15: g4
		16: g5
		31: zone
	]]
	
	if ( not (channel == 31 or channel == 2 or (channel >= 12 and channel <= 16)) ) then return end
	
	if channel == 2  and not NooreTools.vars.watchInTells then return end
	if channel == 31 and not NooreTools.vars.watchInZone then return end
	if channel == 12 and not NooreTools.vars.watchInGuild1 then return end
	if channel == 13 and not NooreTools.vars.watchInGuild2 then return end
	if channel == 14 and not NooreTools.vars.watchInGuild3 then return end
	if channel == 15 and not NooreTools.vars.watchInGuild4 then return end
	if channel == 16 and not NooreTools.vars.watchInGuild5 then return end
	
	local x, y
	if NooreTools.vars.caseSensitive then
		x = text
		y = NooreTools.vars.watchFor
	else
		x = string.upper(text)
		y = string.upper(NooreTools.vars.watchFor)
	end
		
	
	if (x == y) then
		GroupInviteByName(fromName)
	end
end

function NooreTools.Report()
	NooreTools.label:SetText("GS: " .. GetGroupSize() .. " GL: " .. (IsUnitGroupLeader("player") and "YES" or "NO") .. " GUS:" .. GetNumGuilds() .. " G1N:" .. GetGuildName(GetGuildId(1)) .. " Z: " .. GetUnitZone("player"))
end

function NooreTools.Invite(name)
	GroupInviteByName(name)
end

function NooreTools.Kick(name)
	GroupKickByName(name)
end

function NooreTools.Icon(number)
	NooreToolsWindowIcon:SetHidden(false)  -- Show the Icon Display
	NooreToolsWindowIcon:SetTexture(GetLargeAvARankIcon(number))  -- Set the actual texture to use
end
function NooreTools.IconHide()
	NooreToolsWindowIcon:SetHidden(true)  -- Hide the Icon Display
end
function NooreTools.IconShow()
	NooreToolsWindowIcon:SetHidden(false)  -- Show the Icon Display
end